==> kadu-0.3.9.tar.bz2: kadu/modules/speech/translations/speech_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notify by speech</source>
        <translation>Powiadamiaj mową</translation>
    </message>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Mów tylko gdy okno nieaktywne</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Częstotliwość podstawowa</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Synteza Klatta (wymaga dsp)</translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Używaj aRts</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Używaj Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Używaj DSP</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Urządzenie DSP:</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Program mówiący:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Format rozmowy (mężczyzna):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Format rozmowy (kobieta):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Format wiadomości (mężczyzna):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Format powiadomienia (mężczyzna):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Format powiadomienia (kobieta):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Testuj</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Format wiadomości (kobieta):</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Speech</source>
        <translation>Mowa</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a said %1</source>
        <translation>%a napisał %1</translation>
    </message>
    <message>
        <source>woman %a said %1</source>
        <translation>%a napisała %1</translation>
    </message>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>%a zmienił status na %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>%a zmieniła status na %s %d</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/speech/translations/speech_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Mów tylko gdy okno nieaktywne</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Częstotliwość podstawowa</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Synteza Klatta (wymaga dsp)</translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Używaj aRts</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Używaj Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Używaj DSP</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Urządzenie DSP:</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Program mówiący:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Format rozmowy (mężczyzna):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Format rozmowy (kobieta):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Format wiadomości (mężczyzna):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Format powiadomienia (mężczyzna):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Format powiadomienia (kobieta):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Testuj</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Format wiadomości (kobieta):</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Speech</source>
        <translation>Mowa</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Connection error:</source>
        <translation>Błąd połączenia: </translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maksymalna liczba czytanych liter</translation>
    </message>
    <message>
        <source>Message too long (male):</source>
        <translation>Za długa wiadomość (mężczyzna): </translation>
    </message>
    <message>
        <source>Message too long (female):</source>
        <translation>Za długa wiadomość (kobieta): </translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>%a zmienił status na %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>%a zmieniła status na %s %d</translation>
    </message>
    <message>
        <source>Connection error - %1</source>
        <translation>Błąd połączenia - %1</translation>
    </message>
    <message>
        <source>man %a wrote %1</source>
        <translation>%a napisał %1</translation>
    </message>
    <message>
        <source>woman %a wrote %1</source>
        <translation>%a napisała %1</translation>
    </message>
    <message>
        <source>%a wrote long message</source>
        <translation>%a napisał długą wiadomość</translation>
    </message>
</context>
</TS>
